@@ -5,7 +5,7 @@ use warnings;
 
 use Exporter;
 use vars qw(@ISA);
-@ISA=qw(Exporter);
+@ISA = qw(Exporter);
 
 use vars qw(@EXPORT);
 
@@ -13,21 +13,25 @@ use vars qw(@EXPORT);
 
 sub compare_string_arrays
 {
-    my $arr1 = shift;
-    my $arr2 = shift;
-    my $len_cmp = (@$arr1 <=> @$arr2);
+    my $arr1    = shift;
+    my $arr2    = shift;
+    my $len_cmp = ( @$arr1 <=> @$arr2 );
     if ($len_cmp)
     {
-        print STDERR "Len is not the same: Expected " . scalar(@$arr1) . " vs. Result " . scalar(@$arr2) . "\n";
+        print STDERR "Len is not the same: Expected "
+            . scalar(@$arr1)
+            . " vs. Result "
+            . scalar(@$arr2) . "\n";
         return $len_cmp;
     }
     my $i;
-    for($i=0;$i<@$arr1;$i++)
+    for ( $i = 0 ; $i < @$arr1 ; $i++ )
     {
         my $item_cmp = $arr1->[$i] cmp $arr2->[$i];
         if ($item_cmp)
         {
-            print STDERR "Item[$i] is not the same:\nExpected: $arr1->[$i]\nResult: $arr2->[$i]\n";
+            print STDERR
+"Item[$i] is not the same:\nExpected: $arr1->[$i]\nResult: $arr2->[$i]\n";
             return $item_cmp;
         }
     }
